<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>機内モードが無効化されました</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>機内モードが有効化されました</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>無効</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>有効</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>機内モード</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>機内モードの設定</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>機内モード</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth設定</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>オフにしました</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>オフにする</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>オンにする</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth設定</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1が接続されました</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>接続試行中...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>オフにしました</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>%1 に接続されました</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未接続</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Off</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>明るさ</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>ディスプレイ設定</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>ディスプレイ設定</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>明るさ</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>日曜日</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>月</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>火</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>水曜日</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>木</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>金</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>土曜日</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>キーボードレイアウトを追加</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>日時</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12時間表示</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24時間表示</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>時間設定</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>カレンダーを開く</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>月曜日</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>火曜日</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>水曜日</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>木曜日</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>金曜日</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>土曜日</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>日曜日</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>月曜日</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>火曜日</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>水曜日</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>木曜日</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>金曜日</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>土曜日</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>日曜日</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>サイレントモード</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>サイレントモードの設定</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>無効</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>有効</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>サイレントモードが有効化されました</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>サイレントモードが無効化されました</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>サイレントモード</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>目の保護モード</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>目の保護モードが有効化されました</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>目の保護モードが無効化されました</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation type="unfinished">ディスプレイ設定</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished">Off</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>高パフォーマンス</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>バランス</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>省電力モード</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>電源の設定</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>バッテリー残量 %1、残り %2 分</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>バッテリー残量 %1、残り %2 時間 %3 分</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>充電中 %1、充電完了まで %2 分</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>充電中 %1、充電完了まで %2 時間 %3 分</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>バッテリー残量 %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>充電中 %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>バッテリー残量 %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>バッテリー残量 %1、フル充電済み</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>バッテリー</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation type="unfinished">電源の設定</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>シャットダウン</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>サスペンド</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ハイバーネート</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>ロック</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>ログアウト</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源の設定</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>再起動</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished">月曜日</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished">火曜日</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished">水曜日</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished">木曜日</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished">金曜日</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished">土曜日</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished">日曜日</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>May</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jun</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jul</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oct</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nov</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation type="unfinished">カレンダーを開く</translation>
    </message>
    <message>
        <source>monday</source>
        <translation type="unfinished">月曜日</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation type="unfinished">火曜日</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation type="unfinished">水曜日</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation type="unfinished">木曜日</translation>
    </message>
    <message>
        <source>friday</source>
        <translation type="unfinished">金曜日</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation type="unfinished">土曜日</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation type="unfinished">日曜日</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>音量</translation>
    </message>
    <message>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>サウンド</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
